@@ -16,12 +16,12 @@ class CreatePayoutAccount:
         headers = {"Content-type": "application/json",
                    "Accept": "application/json"}
 
-        url_info = urlparse(self.endpoint)
+        url_info = urlparse.urlparse(self.endpoint)
         if url_info.scheme == "https":
-            conn = httplib.HTTPSConnection(
+            conn = http.client.HTTPSConnection(
                 url_info.hostname, url_info.port or 443)
         else:
-            conn = httplib.HTTPConnection(
+            conn = http.client.HTTPSConnection(
                 url_info.hostname, url_info.port or 80)
 
         try:
